# coding: utf-8

"""
    OpenAI Connector server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from openai_connector.models.image_settings import ImageSettings  # noqa: E501

class TestImageSettings(unittest.TestCase):
    """ImageSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ImageSettings:
        """Test ImageSettings
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ImageSettings`
        """
        model = ImageSettings()  # noqa: E501
        if include_optional:
            return ImageSettings(
                model = 'dall-e-2',
                count = 56,
                size = 'auto',
                quality = 'low',
                output_format = 'png'
            )
        else:
            return ImageSettings(
                model = 'dall-e-2',
                count = 56,
                size = 'auto',
                quality = 'low',
                output_format = 'png',
        )
        """

    def testImageSettings(self):
        """Test ImageSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
