# coding: utf-8

"""
    OpenAI Connector server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openai_connector.api.openai_api import OpenaiApi  # noqa: E501


class TestOpenaiApi(unittest.IsolatedAsyncioTestCase):
    """OpenaiApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = OpenaiApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_create_embeddings_v1_openai_embeddings_create_post(self) -> None:
        """Test case for create_embeddings_v1_openai_embeddings_create_post

        Create embeddings  # noqa: E501
        """
        pass

    async def test_generate_image_v1_openai_image_generate_post(self) -> None:
        """Test case for generate_image_v1_openai_image_generate_post

        Generate image  # noqa: E501
        """
        pass

    async def test_generate_response_v1_openai_response_generate_post(self) -> None:
        """Test case for generate_response_v1_openai_response_generate_post

        Generate response  # noqa: E501
        """
        pass

    async def test_stream_response_v1_openai_response_stream_post(self) -> None:
        """Test case for stream_response_v1_openai_response_stream_post

        Stream response  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
