# coding: utf-8

"""
    OpenAI Connector server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from openai_connector.models.chat_role import ChatRole  # noqa: E501

class TestChatRole(unittest.TestCase):
    """ChatRole unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testChatRole(self):
        """Test ChatRole"""
        # inst = ChatRole()

if __name__ == '__main__':
    unittest.main()
